{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                "mkdir",
                "train",
                ";",
                "ln",
                "-s",
                "$(inputs.model.main.path)",
                "train/model",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_forward.path)",
                "train/gene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_backward.path)",
                "train/rgene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_noncoding.path)",
                "train/noncoding",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start.path)",
                "train/start",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop.path)",
                "train/stop",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start1.path)",
                "train/start1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop1.path)",
                "train/stop1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.pwm_dist.path)",
                "train/pwm",
                ";",
                "FragGeneScan",
                "-o",
                "$(runtime.outdir)/predicted_cds",
                "-t",
                "model"
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predictedCDS"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "drop short seqs",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "label": "discard if number of bases is less than this amount",
                    "id": "#discard_short_seqs.cwl/minimum_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/sequences"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "from Bio import SeqIO\ninput_seq_iterator = SeqIO.parse(\"$(inputs.sequences.path)\", \"fasta\")\nshort_seq_iterator = (record for record in input_seq_iterator if len(record.seq) >= $(inputs.minimum_length))\nSeqIO.write(short_seq_iterator, \"$(inputs.sequences.basename).filtered.fasta\", \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).filtered.fasta"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/filtered_sequences"
                }
            ],
            "id": "#discard_short_seqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Find reads with predicted coding sequences above 60 AA in length",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#main/remove_short_pCDS/filtered_sequences",
                    "id": "#main/predictedCDS"
                }
            ],
            "steps": [
                {
                    "doc": "Find reads with predicted coding sequences (pCDS)\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "source": "#main/completeSeq",
                            "id": "#main/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#main/model",
                            "id": "#main/ORF_prediction/model"
                        },
                        {
                            "source": "#main/sequence",
                            "id": "#main/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#main/ORF_prediction/predictedCDS"
                    ],
                    "id": "#main/ORF_prediction"
                },
                {
                    "run": "#discard_short_seqs.cwl",
                    "in": [
                        {
                            "default": 60,
                            "id": "#main/remove_short_pCDS/minimum_length"
                        },
                        {
                            "source": "#main/ORF_prediction/predictedCDS",
                            "id": "#main/remove_short_pCDS/sequences"
                        }
                    ],
                    "out": [
                        "#main/remove_short_pCDS/filtered_sequences"
                    ],
                    "id": "#main/remove_short_pCDS"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
